import { Component, Host, h, Prop, State, Watch } from '@stencil/core';
import { formatName, shorten } from '../../utils/string';
import { useLanguage } from '../../lib/lang';
/**
 * A component which shows a participant's name.
 */
export class DyteNameTag {
  constructor() {
    /** Maximum length of the name */
    this.maxLength = 20;
    /** Whether it is used in a screen share view */
    this.isScreenShare = false;
    /** Language */
    this.t = useLanguage();
    this.length = 13;
  }
  sizeChanged(size) {
    this.length = size === 'sm' ? 8 : 13;
  }
  formatNameTag(name, isSelf) {
    return !this.isScreenShare
      ? isSelf
        ? `${shorten(name, this.length - 3)} (${this.t('you')})`
        : shorten(name, this.length)
      : isSelf
        ? `${this.t('Screen')} - ${shorten(name, this.length - 3)} (${this.t('you')})`
        : `${this.t('Screen')} - ${shorten(name, this.length)}`;
  }
  render() {
    var _a, _b, _c;
    const name = formatName(((_a = this.participant) === null || _a === void 0 ? void 0 : _a.name) || '');
    const isSelf = ((_b = this.participant) === null || _b === void 0 ? void 0 : _b.id) === ((_c = this.meeting) === null || _c === void 0 ? void 0 : _c.self.id);
    return (h(Host, { title: name },
      h("slot", { name: "start" }),
      h("span", { class: "name" }, this.formatNameTag(name, isSelf)),
      h("slot", { name: "end" })));
  }
  static get is() { return "dyte-name-tag"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-name-tag.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-name-tag.css"]
  }; }
  static get properties() { return {
    "participant": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Peer",
        "resolved": "({ readonly id: string; readonly name: string; readonly picture: string; readonly clientSpecificId: any; readonly waitlistStatus: \"accepted\" | \"waiting\" | \"rejected\" | \"none\"; readonly preview: Pick<LocalMediaHandler, \"audioTrack\" | \"videoTrack\" | \"audioEnabled\" | \"videoEnabled\">; readonly role: any; readonly userId: string; readonly organizationId: string; readonly supportsRemoteControl: boolean; readonly device: DeviceConfig; readonly audioTrack: MediaStreamTrack; readonly rawAudioTrack: MediaStreamTrack; readonly addAudioMiddleware: (audioMiddleware: AudioMiddleware) => Promise<{ success: boolean; message: string; }>; readonly removeAudioMiddleware: (audioMiddleware: AudioMiddleware) => Promise<{ success: boolean; message: string; }>; readonly videoTrack: MediaStreamTrack; readonly rawVideoTrack: MediaStreamTrack; readonly addVideoMiddleware: (videoMiddleware: VideoMiddleware) => Promise<{ success: boolean; message: string; }>; readonly removeVideoMiddleware: (videoMiddleware: VideoMiddleware) => Promise<{ success: boolean; message: string; }>; readonly screenShareTracks: { audio?: MediaStreamTrack; video?: MediaStreamTrack; }; readonly audioEnabled: boolean; readonly videoEnabled: boolean; readonly screenShareEnabled: boolean; readonly mediaPermissions: { audio?: \"NOT_REQUESTED\" | \"ACCEPTED\" | \"DENIED\" | \"SYSTEM_DENIED\" | \"COULD_NOT_START\"; video?: \"NOT_REQUESTED\" | \"ACCEPTED\" | \"DENIED\" | \"SYSTEM_DENIED\" | \"COULD_NOT_START\"; screenshare?: \"NOT_REQUESTED\" | \"ACCEPTED\" | \"DENIED\" | \"SYSTEM_DENIED\" | \"COULD_NOT_START\"; }; readonly permissions: DytePermissionsPreset | DytePermissionsPresetV1; readonly suggestedTheme: DyteThemePresetV1 | DyteThemePreset; readonly roomJoined: boolean; readonly setName: (name: string) => void; readonly setupTracks: (options?: { video?: boolean; audio?: boolean; }) => Promise<void>; readonly enableAudio: () => Promise<void>; readonly enableVideo: () => Promise<void>; readonly enableScreenShare: () => Promise<void>; readonly disableAudio: () => Promise<void>; readonly disableVideo: () => Promise<void>; readonly disableScreenShare: () => Promise<void>; readonly enablePreview: (options?: { audio?: boolean; video?: boolean; }) => Promise<void>; readonly disablePreview: (options?: { audio?: boolean; video?: boolean; }) => Promise<void>; readonly getCurrentDevices: () => { audio: MediaDeviceInfo; video: MediaDeviceInfo; speaker: MediaDeviceInfo; }; readonly getAudioDevices: () => MediaDeviceInfo[]; readonly getVideoDevices: () => MediaDeviceInfo[]; readonly getSpeakerDevices: () => MediaDeviceInfo[]; readonly getDeviceById: (deviceId: string, kind: \"audio\" | \"video\" | \"speaker\") => MediaDeviceInfo; readonly getAllDevices: () => MediaDeviceInfo[]; readonly setIsPinned: (isPinned: boolean, emitEvent?: boolean) => void; readonly isPinned: boolean; readonly pin: () => Promise<WebsocketMessage>; readonly unpin: () => Promise<WebsocketMessage>; readonly setDevice: (device: MediaDeviceInfo, preview?: boolean) => Promise<void>; readonly emit: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", ...args: any[]) => boolean; readonly on: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => void) => DyteSelf; readonly addListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly off: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly once: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly prependListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly prependOnceListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly removeListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly removeAllListeners: (event?: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => DyteSelf; readonly listeners: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => Function[]; readonly listenerCount: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => number; readonly setMaxListeners: (n: number) => DyteSelf; readonly getMaxListeners: () => number; readonly rawListeners: (eventName: string | symbol) => Function[]; readonly eventNames: () => (string | symbol)[]; }) | ({ readonly id: string; readonly userId: string; readonly name: string; readonly picture: string; readonly isHost: boolean; readonly clientSpecificId?: string; readonly flags: { [key: string]: string | boolean; }; readonly device: DeviceConfig; readonly videoTrack: MediaStreamTrack; readonly audioTrack: MediaStreamTrack; readonly screenShareTracks: { audio: MediaStreamTrack; video: MediaStreamTrack; }; readonly videoEnabled: boolean; readonly audioEnabled: boolean; readonly screenShareEnabled: boolean; readonly supportsRemoteControl: boolean; readonly setVideoEnabled: (videoEnabled: boolean, emitEvent?: boolean) => void; readonly setAudioEnabled: (audioEnabled: boolean, emitEvent?: boolean) => void; readonly setScreenShareEnabled: (screenShareEnabled: boolean, emitEvent?: boolean) => void; readonly pin: () => Promise<WebsocketMessage>; readonly unpin: () => Promise<WebsocketMessage>; readonly setIsPinned: (isPinned: boolean, emitEvent?: boolean) => void; readonly disableAudio: () => Promise<void>; readonly kick: () => Promise<void>; readonly disableVideo: () => Promise<void>; readonly isPinned: boolean; readonly emit: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", ...args: any[]) => boolean; readonly on: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => void) => DyteParticipant; readonly addListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly off: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly once: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly prependListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly prependOnceListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly removeListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly removeAllListeners: (event?: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => DyteParticipant; readonly listeners: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => Function[]; readonly listenerCount: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => number; readonly setMaxListeners: (n: number) => DyteParticipant; readonly getMaxListeners: () => number; readonly rawListeners: (eventName: string | symbol) => Function[]; readonly eventNames: () => (string | symbol)[]; })",
        "references": {
          "Peer": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Participant object"
      }
    },
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "maxLength": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Maximum length of the name"
      },
      "attribute": "max-length",
      "reflect": false,
      "defaultValue": "20"
    },
    "isScreenShare": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether it is used in a screen share view"
      },
      "attribute": "is-screen-share",
      "reflect": false,
      "defaultValue": "false"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "length": {}
  }; }
  static get watchers() { return [{
      "propName": "size",
      "methodName": "sizeChanged"
    }]; }
}
