import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { d as defaultIconPack } from './default-icon-pack.js';
import { u as useLanguage } from './index2.js';
import { o as onChange, s as state } from './store.js';
import { i as isV2Theme } from './versionTwoApis.js';
import { d as defineCustomElement$4 } from './dyte-controlbar-button2.js';
import { d as defineCustomElement$3 } from './dyte-icon2.js';
import { d as defineCustomElement$2 } from './dyte-spinner2.js';

const dyteParticipantsToggleCss = ":host{display:block;font-family:var(--dyte-font-family, sans-serif)}";

const DyteParticipantsToggle$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.stateUpdate = createEvent(this, "dyteStateUpdate", 7);
    /** Variant */
    this.variant = 'button';
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.participantsActive = false;
  }
  connectedCallback() {
    this.statesChanged(this.states);
    onChange('sidebar', () => this.statesChanged());
  }
  statesChanged(s) {
    const states = s || state;
    if (states != null) {
      this.participantsActive = states.activeSidebar === true && states.sidebar === 'participants';
    }
  }
  toggleParticipantsTab() {
    const states = this.states || state;
    this.participantsActive = !((states === null || states === void 0 ? void 0 : states.activeSidebar) && (states === null || states === void 0 ? void 0 : states.sidebar) === 'participants');
    state.activeSidebar = this.participantsActive;
    state.sidebar = this.participantsActive ? 'participants' : 'none';
    this.stateUpdate.emit({
      activeSidebar: this.participantsActive,
      sidebar: this.participantsActive ? 'participants' : 'none',
    });
  }
  render() {
    var _a, _b, _c, _d;
    const text = this.t('participants');
    const theme = (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.suggestedTheme;
    if (theme &&
      !isV2Theme(theme) &&
      !((_d = (_c = (_b = theme) === null || _b === void 0 ? void 0 : _b.controlBar) === null || _c === void 0 ? void 0 : _c.elements) === null || _d === void 0 ? void 0 : _d.participants))
      return;
    return (h(Host, { title: text }, h("dyte-controlbar-button", { part: "controlbar-button", size: this.size, iconPack: this.iconPack, class: { active: this.participantsActive }, onClick: () => this.toggleParticipantsTab(), icon: this.iconPack.participants, label: text, variant: this.variant })));
  }
  static get watchers() { return {
    "states": ["statesChanged"]
  }; }
  static get style() { return dyteParticipantsToggleCss; }
}, [1, "dyte-participants-toggle", {
    "variant": [513],
    "meeting": [16],
    "states": [16],
    "size": [513],
    "iconPack": [16],
    "t": [16],
    "participantsActive": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-participants-toggle", "dyte-controlbar-button", "dyte-icon", "dyte-spinner"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-participants-toggle":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteParticipantsToggle$1);
      }
      break;
    case "dyte-controlbar-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "dyte-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const DyteParticipantsToggle = DyteParticipantsToggle$1;
const defineCustomElement = defineCustomElement$1;

export { DyteParticipantsToggle, defineCustomElement };
